from setuptools import setup 
setup(name='sfxcentralconfig',
      version='0.2',
      description='operation and library',
      packages=['sfxcentralconfig'],
      author_email='vardhinenimanoj4@gmail.com',
      zip_safe=False)

